@@ -3,6 +3,9 @@ import os
 
 def union_find():
     curr_path = os.path.dirname(__file__)
+    print(curr_path)
+    return curr_path
+    """
     file_path = os.path.join(curr_path, './union_find.py')
     union_find_code = ""
     with open(file_path, 'r') as f:
@@ -23,3 +26,4 @@ def trie():
     f.close()
     pyperclip.copy(trie_code)
     return trie_code
+"""
\ No newline at end of file
